/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.controller;

import org.eclipse.jgit.api.errors.GitAPIException;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import ru.ulstu.extractor.model.Commit;
import ru.ulstu.extractor.service.GitRepositoryService;
import ru.ulstu.extractor.service.IndexService;

import java.io.IOException;
import java.util.List;

import static ru.ulstu.extractor.controller.RepoController.URL;

@RestController
@RequestMapping(URL)
public class RepoController {
    public static final String URL = "/";
    private final GitRepositoryService gitRepositoryService;
    private final IndexService indexService;

    public RepoController(GitRepositoryService gitRepositoryService,
                          IndexService indexService) {
        this.gitRepositoryService = gitRepositoryService;
        this.indexService = indexService;
    }

    @GetMapping("commits")
    public List<Commit> getCommits(@RequestParam("repositoryUrl") String repositoryUrl,
                                   @RequestParam("branchName") String branchName) throws GitAPIException, IOException {
        return gitRepositoryService.getCommits(repositoryUrl, branchName);
    }

    @GetMapping("index")
    public Boolean indexRepository(@RequestParam("repositoryUrl") String repositoryUrl,
                                   @RequestParam("branchName") String branchName) throws GitAPIException, IOException {
        indexService.index(repositoryUrl, branchName);
        return true;
    }

}
