/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import ru.ulstu.extractor.repository.CommitRepository;

import java.util.List;
import java.util.stream.Collectors;

import static ru.ulstu.extractor.controller.Route.STATISTIC;

@Controller
public class StatisticController {
    private final CommitRepository commitRepository;

    public StatisticController(CommitRepository commitRepository) {
        this.commitRepository = commitRepository;
    }

    @GetMapping(STATISTIC)
    public String indexBranch(Model model) {
        List<Object[]> authorCommits = commitRepository.getCommitAuthorStatistic().stream()
                .map(stat -> new Object[]{stat.getAuthor(), stat.getCountCommit()})
                .collect(Collectors.toList());
        model.addAttribute("commitAuthorData", authorCommits);
        List<Object[]> urlCommits = commitRepository.getCommitUrlStatistic().stream()
                .map(stat -> new Object[]{stat.getUrl(), stat.getCountCommit()})
                .collect(Collectors.toList());
        model.addAttribute("commitUrlData", urlCommits);
        List<Object[]> timeCommits = commitRepository.getCommitTimeStatistic().stream()
                .map(stat -> new Object[]{stat.getDate(), stat.getCountCommit()})
                .collect(Collectors.toList());
        model.addAttribute("commitTimeData", timeCommits);
        String[] date = new String[timeCommits.size()];
        for (int i = 0; i < timeCommits.size(); i++) {
            date[i] = timeCommits.get(i)[0].toString();
        }
        model.addAttribute("dates", date);
        String[] url = new String[urlCommits.size()];
        for (int i = 0; i < urlCommits.size(); i++) {
            url[i] = urlCommits.get(i)[0].toString().substring(urlCommits.get(i)[0].toString().lastIndexOf("/") + 1);
        }
        model.addAttribute("urls", url);

        return STATISTIC;
    }
}
